==> mediawiki-1.26.2-1-any.pkg.tar.xz: usr/share/webapps/mediawiki/languages/messages/MessagesLzz.php <==
<?php
/** Lazuri (Lazuri)
 *
 * To improve a translation please visit https://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Bombola
 * @author Ceas08
 * @author Dato deutschland
 * @author Dawid Deutschland
 * @author Erdemaslancan
 * @author Ibero-kolxi
 * @author Reedy
 * @author The Evil IP address
 */

$fallback = 'tr';

$namespaceNames = array(
	NS_MEDIA            => 'Medya',
	NS_SPECIAL          => 'Doxmeli',
	NS_TALK             => 'Ğarğala',
	NS_USER             => 'Maxmare',
	NS_USER_TALK        => 'Maxmare_mesaji',
	NS_PROJECT_TALK     => '$1_ğarğala',
	NS_FILE             => 'Dosya',
	NS_FILE_TALK        => 'Dosya_ğarğala',
	NS_MEDIAWIKI        => 'MediaWiki',
	NS_MEDIAWIKI_TALK   => 'MediaWiki_ğarğala',
	NS_TEMPLATE         => 'Şabloni',
	NS_TEMPLATE_TALK    => 'Şabloni_ğarğala',
	NS_HELP             => 'Meşvela',
	NS_HELP_TALK        => 'Meşvela_ğarğala',
	NS_CATEGORY         => 'Kʼatʼegori',
	NS_CATEGORY_TALK    => 'Kʼatʼegori_ğarğala',
);

$namespaceAliases = array(
	// Turkish namespace names.
	'Medya'              => NS_MEDIA,
	'Özel'               => NS_SPECIAL,
	'Tartışma'           => NS_TALK,
	'Kullanıcı'          => NS_USER,
	'Kullanıcı_mesaj'    => NS_USER_TALK,
	'$1_tartışma'        => NS_PROJECT_TALK,
	'Dosya'              => NS_FILE,
	'Dosya_tartışma'     => NS_FILE_TALK,
	'MediaWiki_tartışma' => NS_MEDIAWIKI_TALK,
	'Şablon'             => NS_TEMPLATE,
	'Şablon_tartışma'    => NS_TEMPLATE_TALK,
	'Yardım'             => NS_HELP,
	'Yardım_tartışma'    => NS_HELP_TALK,
	'Kategori'           => NS_CATEGORY,
	'Kategori_tartışma'  => NS_CATEGORY_TALK,
);

==> mediawiki-1.30.0-1-any.pkg.tar.xz: usr/share/webapps/mediawiki/languages/messages/MessagesLzz.php <==
<?php
/** Lazuri (Lazuri)
 *
 * To improve a translation please visit https://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Bombola
 * @author Ceas08
 * @author Dato deutschland
 * @author Dawid Deutschland
 * @author Erdemaslancan
 * @author Ibero-kolxi
 * @author Reedy
 * @author The Evil IP address
 */

$fallback = 'tr';

$namespaceNames = [
	NS_MEDIA            => 'Medya',
	NS_SPECIAL          => 'Doxmeli',
	NS_TALK             => 'Ğarğala',
	NS_USER             => 'Maxmare',
	NS_USER_TALK        => 'Maxmare_mesaji',
	NS_PROJECT_TALK     => '$1_ğarğala',
	NS_FILE             => 'Dosya',
	NS_FILE_TALK        => 'Dosya_ğarğala',
	NS_MEDIAWIKI        => 'MediaWiki',
	NS_MEDIAWIKI_TALK   => 'MediaWiki_ğarğala',
	NS_TEMPLATE         => 'Şabloni',
	NS_TEMPLATE_TALK    => 'Şabloni_ğarğala',
	NS_HELP             => 'Meşvela',
	NS_HELP_TALK        => 'Meşvela_ğarğala',
	NS_CATEGORY         => 'Kʼatʼegori',
	NS_CATEGORY_TALK    => 'Kʼatʼegori_ğarğala',
];

$namespaceAliases = [
	// Turkish namespace names.
	'Medya'              => NS_MEDIA,
	'Özel'               => NS_SPECIAL,
	'Tartışma'           => NS_TALK,
	'Kullanıcı'          => NS_USER,
	'Kullanıcı_mesaj'    => NS_USER_TALK,
	'$1_tartışma'        => NS_PROJECT_TALK,
	'Dosya'              => NS_FILE,
	'Dosya_tartışma'     => NS_FILE_TALK,
	'MediaWiki_tartışma' => NS_MEDIAWIKI_TALK,
	'Şablon'             => NS_TEMPLATE,
	'Şablon_tartışma'    => NS_TEMPLATE_TALK,
	'Yardım'             => NS_HELP,
	'Yardım_tartışma'    => NS_HELP_TALK,
	'Kategori'           => NS_CATEGORY,
	'Kategori_tartışma'  => NS_CATEGORY_TALK,
];
